# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Match Service V2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ApiMatchFunctionConfig(Model):
    """Api match function config (api.MatchFunctionConfig)

    Properties:
        match_function: (match_function) REQUIRED str

        url: (url) REQUIRED str

        service_app_name: (serviceAppName) OPTIONAL str
    """

    # region fields

    match_function: str  # REQUIRED
    url: str  # REQUIRED
    service_app_name: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_match_function(self, value: str) -> ApiMatchFunctionConfig:
        self.match_function = value
        return self

    def with_url(self, value: str) -> ApiMatchFunctionConfig:
        self.url = value
        return self

    def with_service_app_name(self, value: str) -> ApiMatchFunctionConfig:
        self.service_app_name = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "match_function"):
            result["match_function"] = str(self.match_function)
        elif include_empty:
            result["match_function"] = ""
        if hasattr(self, "url"):
            result["url"] = str(self.url)
        elif include_empty:
            result["url"] = ""
        if hasattr(self, "service_app_name"):
            result["serviceAppName"] = str(self.service_app_name)
        elif include_empty:
            result["serviceAppName"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        match_function: str,
        url: str,
        service_app_name: Optional[str] = None,
        **kwargs,
    ) -> ApiMatchFunctionConfig:
        instance = cls()
        instance.match_function = match_function
        instance.url = url
        if service_app_name is not None:
            instance.service_app_name = service_app_name
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiMatchFunctionConfig:
        instance = cls()
        if not dict_:
            return instance
        if "match_function" in dict_ and dict_["match_function"] is not None:
            instance.match_function = str(dict_["match_function"])
        elif include_empty:
            instance.match_function = ""
        if "url" in dict_ and dict_["url"] is not None:
            instance.url = str(dict_["url"])
        elif include_empty:
            instance.url = ""
        if "serviceAppName" in dict_ and dict_["serviceAppName"] is not None:
            instance.service_app_name = str(dict_["serviceAppName"])
        elif include_empty:
            instance.service_app_name = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiMatchFunctionConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiMatchFunctionConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiMatchFunctionConfig,
        List[ApiMatchFunctionConfig],
        Dict[Any, ApiMatchFunctionConfig],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "match_function": "match_function",
            "url": "url",
            "serviceAppName": "service_app_name",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "match_function": True,
            "url": True,
            "serviceAppName": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Match Service V2."""

__version__ = "2.31.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_match_pool_tickets import AdminGetMatchPoolTickets
from .create_match_pool import CreateMatchPool
from .delete_match_pool import DeleteMatchPool
from .get_player_metric import GetPlayerMetric
from .match_pool_details import MatchPoolDetails
from .match_pool_list import MatchPoolList
from .match_pool_metric import MatchPoolMetric
from .post_match_error_metric import PostMatchErrorMetric
from .public_get_player_metric import PublicGetPlayerMetric
from .update_match_pool import UpdateMatchPool



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApiListRuleSetsResponse
from ..models import ApiRuleSetPayload
from ..models import ResponseError

from ..operations.rule_sets import CreateRuleSet
from ..operations.rule_sets import DeleteRuleSet
from ..operations.rule_sets import RuleSetDetails
from ..operations.rule_sets import RuleSetList
from ..operations.rule_sets import UpdateRuleSet


@same_doc_as(CreateRuleSet)
def create_rule_set(
    body: ApiRuleSetPayload,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a match rule set (CreateRuleSet)

    Creates a new rules set.

    A rule set has a name and contains arbitrary data which is meaningful to some particular match function(s)
    The name is used for a match pool to select the ruleset data that should be sent to the match function when matchmaking in that pool.

    To use custom rules set please set enable_custom_match_function=true. Default (false).

    When custom enable_custom_match_function=true, the ruleset will only validate if the rule is valid json.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets

        method: POST

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiRuleSetPayload in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateRuleSet.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateRuleSet)
async def create_rule_set_async(
    body: ApiRuleSetPayload,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a match rule set (CreateRuleSet)

    Creates a new rules set.

    A rule set has a name and contains arbitrary data which is meaningful to some particular match function(s)
    The name is used for a match pool to select the ruleset data that should be sent to the match function when matchmaking in that pool.

    To use custom rules set please set enable_custom_match_function=true. Default (false).

    When custom enable_custom_match_function=true, the ruleset will only validate if the rule is valid json.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets

        method: POST

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiRuleSetPayload in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateRuleSet.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteRuleSet)
def delete_rule_set(
    ruleset: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a rule set (DeleteRuleSet)

    Deletes an existing rule set.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets/{ruleset}

        method: DELETE

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ruleset: (ruleset) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteRuleSet.create(
        ruleset=ruleset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteRuleSet)
async def delete_rule_set_async(
    ruleset: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a rule set (DeleteRuleSet)

    Deletes an existing rule set.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets/{ruleset}

        method: DELETE

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ruleset: (ruleset) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteRuleSet.create(
        ruleset=ruleset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RuleSetDetails)
def rule_set_details(
    ruleset: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get details for a specific rule set (RuleSetDetails)

    Get details for a specific rule set

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets/{ruleset}

        method: GET

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ruleset: (ruleset) REQUIRED str in path

    Responses:
        200: OK - ApiRuleSetPayload (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RuleSetDetails.create(
        ruleset=ruleset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RuleSetDetails)
async def rule_set_details_async(
    ruleset: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get details for a specific rule set (RuleSetDetails)

    Get details for a specific rule set

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets/{ruleset}

        method: GET

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ruleset: (ruleset) REQUIRED str in path

    Responses:
        200: OK - ApiRuleSetPayload (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RuleSetDetails.create(
        ruleset=ruleset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RuleSetList)
def rule_set_list(
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """List existing rule sets (RuleSetList)

    List rule sets.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets

        method: GET

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApiListRuleSetsResponse (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RuleSetList.create(
        limit=limit,
        name=name,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RuleSetList)
async def rule_set_list_async(
    limit: Optional[int] = None,
    name: Optional[str] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """List existing rule sets (RuleSetList)

    List rule sets.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets

        method: GET

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApiListRuleSetsResponse (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RuleSetList.create(
        limit=limit,
        name=name,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateRuleSet)
def update_rule_set(
    body: ApiRuleSetPayload,
    ruleset: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update a match rule set (UpdateRuleSet)

    Updates an existing matchmaking rule set.

    To use custom rules set please set enable_custom_match_function=true. Default (false).

    When custom enable_custom_match_function=true, the ruleset will only validate if the rule is valid json.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets/{ruleset}

        method: PUT

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiRuleSetPayload in body

        namespace: (namespace) REQUIRED str in path

        ruleset: (ruleset) REQUIRED str in path

    Responses:
        200: OK - ApiRuleSetPayload (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateRuleSet.create(
        body=body,
        ruleset=ruleset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateRuleSet)
async def update_rule_set_async(
    body: ApiRuleSetPayload,
    ruleset: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update a match rule set (UpdateRuleSet)

    Updates an existing matchmaking rule set.

    To use custom rules set please set enable_custom_match_function=true. Default (false).

    When custom enable_custom_match_function=true, the ruleset will only validate if the rule is valid json.

    Properties:
        url: /match2/v1/namespaces/{namespace}/rulesets/{ruleset}

        method: PUT

        tags: ["Rule-Sets", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiRuleSetPayload in body

        namespace: (namespace) REQUIRED str in path

        ruleset: (ruleset) REQUIRED str in path

    Responses:
        200: OK - ApiRuleSetPayload (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateRuleSet.create(
        body=body,
        ruleset=ruleset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Match Service V2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.api_team import ApiTeam
from ..models.api_ticket import ApiTicket


class ApiBackfillProposalResponse(Model):
    """Api backfill proposal response (api.BackfillProposalResponse)

    Properties:
        backfill_ticket_id: (backfillTicketID) OPTIONAL str

        created_at: (createdAt) OPTIONAL str

        match_pool: (matchPool) OPTIONAL str

        match_session_id: (matchSessionID) OPTIONAL str

        proposal_id: (proposalID) OPTIONAL str

        proposed_teams: (proposedTeams) OPTIONAL List[ApiTeam]

        tickets: (tickets) OPTIONAL List[ApiTicket]
    """

    # region fields

    backfill_ticket_id: str  # OPTIONAL
    created_at: str  # OPTIONAL
    match_pool: str  # OPTIONAL
    match_session_id: str  # OPTIONAL
    proposal_id: str  # OPTIONAL
    proposed_teams: List[ApiTeam]  # OPTIONAL
    tickets: List[ApiTicket]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_backfill_ticket_id(self, value: str) -> ApiBackfillProposalResponse:
        self.backfill_ticket_id = value
        return self

    def with_created_at(self, value: str) -> ApiBackfillProposalResponse:
        self.created_at = value
        return self

    def with_match_pool(self, value: str) -> ApiBackfillProposalResponse:
        self.match_pool = value
        return self

    def with_match_session_id(self, value: str) -> ApiBackfillProposalResponse:
        self.match_session_id = value
        return self

    def with_proposal_id(self, value: str) -> ApiBackfillProposalResponse:
        self.proposal_id = value
        return self

    def with_proposed_teams(self, value: List[ApiTeam]) -> ApiBackfillProposalResponse:
        self.proposed_teams = value
        return self

    def with_tickets(self, value: List[ApiTicket]) -> ApiBackfillProposalResponse:
        self.tickets = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "backfill_ticket_id"):
            result["backfillTicketID"] = str(self.backfill_ticket_id)
        elif include_empty:
            result["backfillTicketID"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "match_pool"):
            result["matchPool"] = str(self.match_pool)
        elif include_empty:
            result["matchPool"] = ""
        if hasattr(self, "match_session_id"):
            result["matchSessionID"] = str(self.match_session_id)
        elif include_empty:
            result["matchSessionID"] = ""
        if hasattr(self, "proposal_id"):
            result["proposalID"] = str(self.proposal_id)
        elif include_empty:
            result["proposalID"] = ""
        if hasattr(self, "proposed_teams"):
            result["proposedTeams"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.proposed_teams
            ]
        elif include_empty:
            result["proposedTeams"] = []
        if hasattr(self, "tickets"):
            result["tickets"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.tickets
            ]
        elif include_empty:
            result["tickets"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        backfill_ticket_id: Optional[str] = None,
        created_at: Optional[str] = None,
        match_pool: Optional[str] = None,
        match_session_id: Optional[str] = None,
        proposal_id: Optional[str] = None,
        proposed_teams: Optional[List[ApiTeam]] = None,
        tickets: Optional[List[ApiTicket]] = None,
        **kwargs,
    ) -> ApiBackfillProposalResponse:
        instance = cls()
        if backfill_ticket_id is not None:
            instance.backfill_ticket_id = backfill_ticket_id
        if created_at is not None:
            instance.created_at = created_at
        if match_pool is not None:
            instance.match_pool = match_pool
        if match_session_id is not None:
            instance.match_session_id = match_session_id
        if proposal_id is not None:
            instance.proposal_id = proposal_id
        if proposed_teams is not None:
            instance.proposed_teams = proposed_teams
        if tickets is not None:
            instance.tickets = tickets
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiBackfillProposalResponse:
        instance = cls()
        if not dict_:
            return instance
        if "backfillTicketID" in dict_ and dict_["backfillTicketID"] is not None:
            instance.backfill_ticket_id = str(dict_["backfillTicketID"])
        elif include_empty:
            instance.backfill_ticket_id = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "matchPool" in dict_ and dict_["matchPool"] is not None:
            instance.match_pool = str(dict_["matchPool"])
        elif include_empty:
            instance.match_pool = ""
        if "matchSessionID" in dict_ and dict_["matchSessionID"] is not None:
            instance.match_session_id = str(dict_["matchSessionID"])
        elif include_empty:
            instance.match_session_id = ""
        if "proposalID" in dict_ and dict_["proposalID"] is not None:
            instance.proposal_id = str(dict_["proposalID"])
        elif include_empty:
            instance.proposal_id = ""
        if "proposedTeams" in dict_ and dict_["proposedTeams"] is not None:
            instance.proposed_teams = [
                ApiTeam.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["proposedTeams"]
            ]
        elif include_empty:
            instance.proposed_teams = []
        if "tickets" in dict_ and dict_["tickets"] is not None:
            instance.tickets = [
                ApiTicket.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["tickets"]
            ]
        elif include_empty:
            instance.tickets = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiBackfillProposalResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiBackfillProposalResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiBackfillProposalResponse,
        List[ApiBackfillProposalResponse],
        Dict[Any, ApiBackfillProposalResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "backfillTicketID": "backfill_ticket_id",
            "createdAt": "created_at",
            "matchPool": "match_pool",
            "matchSessionID": "match_session_id",
            "proposalID": "proposal_id",
            "proposedTeams": "proposed_teams",
            "tickets": "tickets",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "backfillTicketID": False,
            "createdAt": False,
            "matchPool": False,
            "matchSessionID": False,
            "proposalID": False,
            "proposedTeams": False,
            "tickets": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Match Service V2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.models_server import ModelsServer


class ModelsDSInformation(Model):
    """Models DS information (models.DSInformation)

    Properties:
        min_players: (MinPlayers) REQUIRED int

        requested_at: (RequestedAt) REQUIRED str

        requested_regions: (RequestedRegions) REQUIRED List[str]

        server: (Server) REQUIRED ModelsServer

        status: (Status) REQUIRED str
    """

    # region fields

    min_players: int  # REQUIRED
    requested_at: str  # REQUIRED
    requested_regions: List[str]  # REQUIRED
    server: ModelsServer  # REQUIRED
    status: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_min_players(self, value: int) -> ModelsDSInformation:
        self.min_players = value
        return self

    def with_requested_at(self, value: str) -> ModelsDSInformation:
        self.requested_at = value
        return self

    def with_requested_regions(self, value: List[str]) -> ModelsDSInformation:
        self.requested_regions = value
        return self

    def with_server(self, value: ModelsServer) -> ModelsDSInformation:
        self.server = value
        return self

    def with_status(self, value: str) -> ModelsDSInformation:
        self.status = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "min_players"):
            result["MinPlayers"] = int(self.min_players)
        elif include_empty:
            result["MinPlayers"] = 0
        if hasattr(self, "requested_at"):
            result["RequestedAt"] = str(self.requested_at)
        elif include_empty:
            result["RequestedAt"] = ""
        if hasattr(self, "requested_regions"):
            result["RequestedRegions"] = [str(i0) for i0 in self.requested_regions]
        elif include_empty:
            result["RequestedRegions"] = []
        if hasattr(self, "server"):
            result["Server"] = self.server.to_dict(include_empty=include_empty)
        elif include_empty:
            result["Server"] = ModelsServer()
        if hasattr(self, "status"):
            result["Status"] = str(self.status)
        elif include_empty:
            result["Status"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        min_players: int,
        requested_at: str,
        requested_regions: List[str],
        server: ModelsServer,
        status: str,
        **kwargs,
    ) -> ModelsDSInformation:
        instance = cls()
        instance.min_players = min_players
        instance.requested_at = requested_at
        instance.requested_regions = requested_regions
        instance.server = server
        instance.status = status
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsDSInformation:
        instance = cls()
        if not dict_:
            return instance
        if "MinPlayers" in dict_ and dict_["MinPlayers"] is not None:
            instance.min_players = int(dict_["MinPlayers"])
        elif include_empty:
            instance.min_players = 0
        if "RequestedAt" in dict_ and dict_["RequestedAt"] is not None:
            instance.requested_at = str(dict_["RequestedAt"])
        elif include_empty:
            instance.requested_at = ""
        if "RequestedRegions" in dict_ and dict_["RequestedRegions"] is not None:
            instance.requested_regions = [str(i0) for i0 in dict_["RequestedRegions"]]
        elif include_empty:
            instance.requested_regions = []
        if "Server" in dict_ and dict_["Server"] is not None:
            instance.server = ModelsServer.create_from_dict(
                dict_["Server"], include_empty=include_empty
            )
        elif include_empty:
            instance.server = ModelsServer()
        if "Status" in dict_ and dict_["Status"] is not None:
            instance.status = str(dict_["Status"])
        elif include_empty:
            instance.status = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsDSInformation]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsDSInformation]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsDSInformation, List[ModelsDSInformation], Dict[Any, ModelsDSInformation]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "MinPlayers": "min_players",
            "RequestedAt": "requested_at",
            "RequestedRegions": "requested_regions",
            "Server": "server",
            "Status": "status",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "MinPlayers": True,
            "RequestedAt": True,
            "RequestedRegions": True,
            "Server": True,
            "Status": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Match Service V2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ConfigmodelsNamespaceConfig(Model):
    """Configmodels namespace config (configmodels.NamespaceConfig)

    Properties:
        namespace: (namespace) REQUIRED str

        cross_platform_no_current_platform: (crossPlatformNoCurrentPlatform) OPTIONAL bool

        extra_platforms: (extraPlatforms) OPTIONAL List[str]

        match_any_common: (matchAnyCommon) OPTIONAL bool

        platform_group: (platformGroup) OPTIONAL Dict[str, List[str]]
    """

    # region fields

    namespace: str  # REQUIRED
    cross_platform_no_current_platform: bool  # OPTIONAL
    extra_platforms: List[str]  # OPTIONAL
    match_any_common: bool  # OPTIONAL
    platform_group: Dict[str, List[str]]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_namespace(self, value: str) -> ConfigmodelsNamespaceConfig:
        self.namespace = value
        return self

    def with_cross_platform_no_current_platform(
        self, value: bool
    ) -> ConfigmodelsNamespaceConfig:
        self.cross_platform_no_current_platform = value
        return self

    def with_extra_platforms(self, value: List[str]) -> ConfigmodelsNamespaceConfig:
        self.extra_platforms = value
        return self

    def with_match_any_common(self, value: bool) -> ConfigmodelsNamespaceConfig:
        self.match_any_common = value
        return self

    def with_platform_group(
        self, value: Dict[str, List[str]]
    ) -> ConfigmodelsNamespaceConfig:
        self.platform_group = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "cross_platform_no_current_platform"):
            result["crossPlatformNoCurrentPlatform"] = bool(
                self.cross_platform_no_current_platform
            )
        elif include_empty:
            result["crossPlatformNoCurrentPlatform"] = False
        if hasattr(self, "extra_platforms"):
            result["extraPlatforms"] = [str(i0) for i0 in self.extra_platforms]
        elif include_empty:
            result["extraPlatforms"] = []
        if hasattr(self, "match_any_common"):
            result["matchAnyCommon"] = bool(self.match_any_common)
        elif include_empty:
            result["matchAnyCommon"] = False
        if hasattr(self, "platform_group"):
            result["platformGroup"] = {
                str(k0): [str(i1) for i1 in v0]
                for k0, v0 in self.platform_group.items()
            }
        elif include_empty:
            result["platformGroup"] = {}
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        cross_platform_no_current_platform: Optional[bool] = None,
        extra_platforms: Optional[List[str]] = None,
        match_any_common: Optional[bool] = None,
        platform_group: Optional[Dict[str, List[str]]] = None,
        **kwargs,
    ) -> ConfigmodelsNamespaceConfig:
        instance = cls()
        instance.namespace = namespace
        if cross_platform_no_current_platform is not None:
            instance.cross_platform_no_current_platform = (
                cross_platform_no_current_platform
            )
        if extra_platforms is not None:
            instance.extra_platforms = extra_platforms
        if match_any_common is not None:
            instance.match_any_common = match_any_common
        if platform_group is not None:
            instance.platform_group = platform_group
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ConfigmodelsNamespaceConfig:
        instance = cls()
        if not dict_:
            return instance
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if (
            "crossPlatformNoCurrentPlatform" in dict_
            and dict_["crossPlatformNoCurrentPlatform"] is not None
        ):
            instance.cross_platform_no_current_platform = bool(
                dict_["crossPlatformNoCurrentPlatform"]
            )
        elif include_empty:
            instance.cross_platform_no_current_platform = False
        if "extraPlatforms" in dict_ and dict_["extraPlatforms"] is not None:
            instance.extra_platforms = [str(i0) for i0 in dict_["extraPlatforms"]]
        elif include_empty:
            instance.extra_platforms = []
        if "matchAnyCommon" in dict_ and dict_["matchAnyCommon"] is not None:
            instance.match_any_common = bool(dict_["matchAnyCommon"])
        elif include_empty:
            instance.match_any_common = False
        if "platformGroup" in dict_ and dict_["platformGroup"] is not None:
            instance.platform_group = {
                str(k0): [str(i1) for i1 in v0]
                for k0, v0 in dict_["platformGroup"].items()
            }
        elif include_empty:
            instance.platform_group = {}
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ConfigmodelsNamespaceConfig]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ConfigmodelsNamespaceConfig]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ConfigmodelsNamespaceConfig,
        List[ConfigmodelsNamespaceConfig],
        Dict[Any, ConfigmodelsNamespaceConfig],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
            "crossPlatformNoCurrentPlatform": "cross_platform_no_current_platform",
            "extraPlatforms": "extra_platforms",
            "matchAnyCommon": "match_any_common",
            "platformGroup": "platform_group",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
            "crossPlatformNoCurrentPlatform": False,
            "extraPlatforms": False,
            "matchAnyCommon": False,
            "platformGroup": False,
        }

    # endregion static methods
